#
# spec file for package lvm2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lvm2_version              2.02.120
%define device_mapper_version     1.02.97
%define thin_provisioning_version 0.5.3
%define enable_testsuite 0

Name:           lvm2
Version:        %{lvm2_version}
Release:        75.28
Summary:        Logical Volume Manager Tools
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Base
Url:            http://www.sourceware.org/lvm2/

Source:         ftp://sources.redhat.com/pub/%{name}/LVM2.%{version}.tgz
Source42:       ftp://sources.redhat.com/pub/%{name}/LVM2.%{version}.tgz.asc
Source1:        lvm.conf
Source8:        clvmd.ocf
Source10:       cmirrord.ocf
Source14:       baselibs.conf
Source16:       csm-converter.tar.gz
Source50:       thin-provisioning-tools-v%{thin_provisioning_version}.tar.gz

# Upstream patches first
Patch1:         lvmetad.c-ignore-lvmetad-global-handle-on-disconnect.patch 
Patch2:         alloc-Fix-lvextend-failure-when-varying-stripes.patch
Patch3:         lvmcache-Remove-verbose-msg-when-rescanning-dev.patch
Patch4:         pvcreate-remove-recent-warning-message.patch
Patch5:         pvchange-pvresize-move-exported-VG-check.patch
Patch7:         pvscan-restore-polling-in-autoactivation-handler.patch
Patch8:         lvchange-improve-refresh-for-merging-thin-volume.patch 
Patch9:         log-Add-DM_ABORT_ON_INTERNAL_ERRORS-lvm-override.patch
Patch10:        udev-use-for-SYSTEMD_WANTS-instead-of.patch 
Patch11:        bug-1017034_systemd-use-local-remote-fs-pre.target-instead-of-lo.patch 
Patch12:        bug-1025630_mem-add-extra-mem-pages-for-pthread-stack.patch
# SUSE patches 1000- for LVM, 2000- for device mapper
Patch1001:      improve_probing.diff
Patch1002:      no-inc-audit.diff
Patch1003:      no_buildroot_shared.diff
Patch1004:      sys_mount_instead_linux_fs.diff
Patch1005:      display-dm-name-for-lv-name.diff
Patch1006:      device-mapper-type_punning.diff
Patch1007:      make-mirror-legs-on-different-tag-pvs.patch
Patch1008:      improve-mirror-legs-on-different-tag-pvs.patch
Patch1009:      cmirrord_improvment_performance.patch
Patch1010:      cluster_support_mirrord_log.diff
Patch1011:      lvconvert-cluster-mirrored-disk-failed.patch
Patch1012:      suppress_format1_size_warning.diff
Patch1013:      pvmove_support_clustered_vg.diff
Patch1014:      cmirrord_remove_date_time_from_compilation.patch
Patch1015:      fix-closedown-before-thread-finish.patch
Patch1016:      use-mirrortype-asdefault-whenclvmdrunning.patch
Patch1017:      version-plugins-in-libdir
Patch1018:      fsadm-add-support-for-btrfs.patch
Patch1019:      manpage-lvscan-fix.patch
Patch1020:      dmeventd-fix-dso-name-wrong-compare.patch
Patch1021:      remove-unrecognized-RemoveOnStop-from-lvm2-lvmetad-socket.patch
Patch1022:      fix-build-error-caused-by-commit-b93b8537.patch
%if %{enable_testsuite}
Patch1023:      lvm2-testsuite.patch
%endif
Patch1024:      pvcreate-don-t-support-unpartitioned-DASD-devices-with-CDL-formatted.patch
Patch1025:      libdm-iface-not-output-error-message-inside-retry-loop.patch
Patch1026:      lvm2-lvmetad.service-add-Also-lvm2-lvmetad.socket.patch
Patch1027:      pvcreate-enhance-the-error-message.patch
Patch1028:      bug-1012973_Simplify-special-case-for-md-in-69-dm-lvm-metadata.patch

# device-mapper patches
#suse, bnc#707253(also merged patch for bnc#479104)
Patch2000:      device-mapper-dmsetup-export.patch
Patch2001:      device-mapper-gcc-warnings.patch
Patch2002:      device-mapper-static.patch
Patch2003:      device-mapper-link
Patch2004:      udev_rules-update.diff
Patch2005:      udev-Check-for-DM_NR_VALID_PATHS.patch
Patch2006:      Import-ID_FS_XXX-variables-bnc909358.patch
Patch2007:      10-dm.rules-Reset-state-variable-for-spurious-events.patch
Patch2008:      69-dm-lvm-metad.rules-Do-not-process-rules-for-multi.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libaio-devel
BuildRequires:  libselinux-devel
BuildRequires:  readline-devel
Requires(pre):  systemd-presets-branding
Requires(post): systemd-presets-branding
BuildRequires:  libblkid-devel
BuildRequires:  suse-module-tools
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires:       device-mapper >= %{device_mapper_version}
Provides:       lvm = %version-%release
# Not a real replacement but we drop evms
Provides:       evms = 2.5.5
Provides:       evms-devel = 2.5.5
Provides:       evms-gui = 2.5.5
Provides:       evms-ha = 2.5.5
Obsoletes:      evms <= 2.5.5
Obsoletes:      evms-devel <= 2.5.5
Obsoletes:      evms-gui <= 2.5.5
Obsoletes:      evms-ha <= 2.5.5
%define _udevdir %(pkg-config --variable=udevdir udev)

%if %{defined systemd_requires}
%{systemd_requires}
%endif

%description
Programs and man pages for configuring and using the LVM2 Logical
Volume Manager.


%prep
%setup -q -n LVM2.%{version} -a 50  -a 16 

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch1001 -p1
%patch1002 -p1
%patch1003 -p1
%patch1004 -p1
%patch1005 -p1
%patch1006 -p1
%patch1007 -p1
%patch1008 -p1
%patch1009 -p1
%patch1010 -p1
%patch1011 -p1
%patch1012 -p1
%patch1013 -p1
%patch1014 -p1
%patch1015 -p1
%patch1016 -p1
%patch1017 -p1
%patch1018 -p1
%patch1019 -p1
%patch1020 -p1
%patch1021 -p1
%patch1022 -p1
%if %{enable_testsuite}
%patch1023 -p1
%endif
%patch1024 -p1
%patch1025 -p1
%patch1026 -p1
%patch1027 -p1
%patch1028 -p1

%patch2000 -p1
%patch2001 -p1
%patch2002 -p1
%patch2003 -p1
%patch2004 -p1
%patch2005 -p1
%patch2006 -p1
%patch2007 -p1
%patch2008 -p1

%build
#set path so that thin_check can be found
#export before configure due to bnc#779965
export MODPROBE_CMD=/sbin/modprobe 
export CFLAGS="$RPM_OPT_FLAGS"
export PATH=$PATH:/sbin:/usr/sbin
sed -ie "s/%{device_mapper_version}/1.03.01/g" VERSION_DM
autoreconf -fvi
%configure \
	--prefix=/ \
	--libdir=/%_lib \
	--with-usrlibdir=%_libdir \
	--with-usrsbindir=%_sbindir \
	--sbindir=/sbin \
	--enable-dmeventd \
	--enable-udev_sync \
	--enable-udev_rules \
	--enable-cmdlib \
	--enable-applib \
	--enable-dmeventd \
	--enable-realtime \
	--enable-pkgconfig \
	--enable-selinux \
	--with-clvmd=corosync \
	--with-cluster=internal \
	--datarootdir="%_datadir" \
	--with-default-locking-dir=/run/lock/lvm \
	--enable-cmirrord \
	--enable-lvmetad \
	--with-default-pid-dir=/run \
	--with-default-dm-run-dir=/run \
	--with-default-run-dir=/run/lvm \
	--with-tmpfilesdir=%{_tmpfilesdir} \
	--with-thin=internal \
	--with-device-gid=6 \
	--with-device-mode=0640 \
	--with-device-uid=0 \
	--with-dmeventd-path=/sbin/dmeventd \
	--with-thin-check=%{_sbindir}/thin_check \
	--with-thin-dump=%{_sbindir}/thin_dump \
	--with-thin-repair=%{_sbindir}/thin_repair \
	--with-udev-prefix="%_prefix/" \
    --enable-blkid-wiping

export SUSE_ASNEEDED=0

make %{?_smp_mflags}

#csm convert
pushd bnz
make %{?_smp_mflags}
popd

pushd thin-provisioning-tools-%{thin_provisioning_version}
autoreconf -fiv
%configure --sbindir=/sbin --prefix="%_prefix"
make %{?_smp_mflags}
popd

%install
%make_install
make install_system_dirs DESTDIR="%buildroot"
make install_systemd_units DESTDIR="%buildroot"
make install_systemd_generators DESTDIR="%buildroot"
make install_tmpfiles_configuration DESTDIR="%buildroot"
%if %{enable_testsuite}
make -C test install DESTDIR="%buildroot"
%endif
# Is this directory used anymore?
install -d -m 755 "%buildroot/%_sysconfdir/lvm/metadata"
install -m 644 %{SOURCE1} "%buildroot/%_sysconfdir/lvm/"
mkdir -p "%buildroot/%_initddir"
mkdir -p "%buildroot/%_sbindir"
install -m755 -D %{S:8} "%buildroot/%_prefix/lib/ocf/resource.d/lvm2/clvmd"
install -m755 -D %{S:10} "%buildroot/%_prefix/lib/ocf/resource.d/lvm2/cmirrord"

# Make sure libdevmapper.so.1.02 libdevmapper-event.so.1.02 still available
# on Tumbleweed, as virtualbox.org didn't update their RPMs yet.
rm -f libdm/ioctl/libdevmapper.so daemons/dmeventd/libdevmapper-event.so
sed -i "s/1.03.01/%{device_mapper_version}/" VERSION_DM
make device-mapper
make install_device-mapper DESTDIR=%{buildroot}

pushd "%buildroot/%_lib"
ln -sf liblvm2cmd.so.2.02 liblvm2cmd.so
ln -sf liblvm2app.so.2.2 liblvm2app.so
for i in libdevmapper-event-lvm2{mirror,raid,snapshot,thin}; do
	ln -sf "device-mapper/$i.so" "$i.so"
	ln -sf "device-mapper/$i.so" "$i.so.2.02"
done
popd

pushd "%buildroot/%_sbindir"
ln -sf ../../sbin/lvm lvm
ln -sf ../../sbin/lvmconf lvmconf
popd

pushd "%buildroot/sbin"
ln -sf ../usr/sbin/clvmd clvmd
ln -sf ../usr/sbin/cmirrord cmirrord
popd

#csm-convert
pushd bnz
install -m755 -D csm-converter "%buildroot/%_sbindir/csm-converter"
install -m755 -D csm-converter-helper "%buildroot/%_sbindir/csm-converter-helper"
mv README.csm-converter ..
popd

pushd thin-provisioning-tools-%{thin_provisioning_version}
%make_install
popd

%pre
%service_add_pre blk-availability.service lvm2-monitor.service lvm2-lvmetad.socket lvm2-lvmetad.service 

%post
/sbin/ldconfig
%{?regenerate_initrd_post}
%service_add_post blk-availability.service lvm2-monitor.service lvm2-lvmetad.socket lvm2-lvmetad.service

%posttrans
%{?regenerate_initrd_posttrans}

%preun
%service_del_preun blk-availability.service lvm2-monitor.service lvm2-lvmetad.service 

%postun
/sbin/ldconfig
%service_del_postun blk-availability.service lvm2-monitor.service lvm2-lvmetad.service

%files
%defattr(-,root,root)
%doc README WHATS_NEW doc/*
%dir %{_sysconfdir}/lvm
%dir %{_sysconfdir}/lvm/backup
%dir %{_sysconfdir}/lvm/archive
%dir %{_sysconfdir}/lvm/metadata
%dir %{_sysconfdir}/lvm/profile
%dir %{_sysconfdir}/lvm/cache
%dir /usr/lib/systemd/system-generators
%dir /usr/lib/tmpfiles.d
%ghost %{_sysconfdir}/lvm/cache/.cache
%{_sysconfdir}/lvm/profile/*.profile
%{_sysconfdir}/lvm/lvmlocal.conf
%{_udevdir}/rules.d/11-dm-lvm.rules
%{_udevdir}/rules.d/69-dm-lvm-metad.rules
%{_unitdir}/blk-availability.service
%{_unitdir}/lvm2-monitor.service
%{_unitdir}/lvm2-lvmetad.socket
%{_unitdir}/lvm2-lvmetad.service
%{_unitdir}/lvm2-pvscan@.service
%{_tmpfilesdir}/lvm2.conf
%config(noreplace) %{_sysconfdir}/lvm/lvm.conf
/usr/lib/systemd/system-generators/lvm2-activation-generator
/sbin/blkdeactivate
/sbin/fsadm
/sbin/lv*
/sbin/pv*
/sbin/vg*
%_sbindir/lvm
%_sbindir/lvmconf
%dir /%_lib/device-mapper
/%_lib/device-mapper/libdevmapper-event-lvm2*.so
/%_lib/libdevmapper-event-lvm2*.so
/%_lib/liblvm2cmd.so
/%_lib/liblvm2cmd.so.2.02
/%_lib/liblvm2app.so
/%_lib/liblvm2app.so.2.2
/%_libdir/liblvm2app.so
/%_libdir/liblvm2cmd.so
/%_lib/libdevmapper-event-lvm2*.so.2.02
/%_libdir/libdevmapper-event-lvm2.so
%_mandir/man5/lvm.conf.5.gz
%_mandir/man8/blkdeactivate.8.gz
%_mandir/man8/fsadm.8.gz
%_mandir/man8/lv*.8*
%_mandir/man8/pv*.8*
%_mandir/man8/vg*.8*
%_mandir/man7/lvm*.7*

%package clvm
Url:            http://sources.redhat.com/cluster/clvm/
Version:        %{lvm2_version}
Release:        75.28
BuildRequires:  libcorosync-devel
BuildRequires:  libdlm-devel
Requires:       corosync
Requires:       device-mapper >= %{device_mapper_version}
Requires:       lvm2 = %{version}
Requires:       lvm2-cmirrord
Obsoletes:      cmirrord < %{version}
Provides:       cmirrord = %{version}
Summary:        Clustered LVM2
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Clustering/HA

%description clvm
A daemon for using LVM2 Logival Volumes in a clustered environment.

%files clvm
%defattr(-,root,root)
%{_sbindir}/clvmd
/sbin/clvmd
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/resource.d/lvm2
/usr/lib/ocf/resource.d/lvm2/clvmd
%{_mandir}/man8/clvmd.8.gz
%doc README.csm-converter
%{_sbindir}/csm-converter
%{_sbindir}/csm-converter-helper
%{_unitdir}/lvm2-clvmd.service
%{_unitdir}/lvm2-cluster-activation.service
/usr/lib/systemd/lvm2-cluster-activation

%package cmirrord
Url:            http://www.sourceware.org/lvm2/
Version:        %{lvm2_version}
Release:        75.28
Requires:       corosync
Requires:       device-mapper >= %{device_mapper_version}
Requires:       lvm2 = %{version}
Requires:       lvm2-clvm
Summary:        Clustered RAID 1 support using device-mapper and corosync
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Clustering/HA

%description cmirrord
A daemon for using LVM2 Logival Volumes in a clustered environment.

%files cmirrord
%defattr(-,root,root)
%{_sbindir}/cmirrord
/sbin/cmirrord
/usr/lib/ocf/resource.d/lvm2/cmirrord
%{_mandir}/man8/cmirrord.8.gz
/usr/lib/systemd/system/lvm2-cmirrord.service

%package devel
Version:        %{lvm2_version}
Release:        75.28
Requires:       lvm2 = %{version}
Summary:        Development files for LVM2
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++

%description devel
This package provides development files for the LVM2 Logical Volume Manager.


%files devel
%defattr(-,root,root)
%_includedir/lvm2cmd.h
%_includedir/lvm2app.h
%_libdir/pkgconfig/lvm2app.pc

##########################################
# Subpackage: device-mapper
##########################################
%package -n device-mapper

%ifarch ppc64
Obsoletes:      device-mapper-64bit
%endif
Version:        %{device_mapper_version}
Release:        75.28
Summary:        Device Mapper Tools
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  libexpat-devel
BuildRequires:  libselinux-devel
BuildRequires:  libsepol-devel
BuildRequires:  libstdc++-devel
BuildRequires:  suse-module-tools
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libudev)
Requires:       expat

%if %{defined systemd_requires}
%{systemd_requires}
%endif

%description -n device-mapper
Programs, libraries, and man pages for configuring and using the device
mapper.

%post -n device-mapper
%service_add_post dm-event.service dm-event.socket
/sbin/ldconfig
%{?regenerate_initrd_post}

%posttrans -n device-mapper
%{?regenerate_initrd_posttrans}

%pre -n device-mapper
%service_add_pre dm-event.service dm-event.socket

%preun -n device-mapper
%service_del_preun dm-event.service dm-event.socket

%postun -n device-mapper
%service_del_postun dm-event.service dm-event.socket
/sbin/ldconfig

%files -n device-mapper
%defattr(-,root,root)
%doc INSTALL COPYING COPYING.LIB README
%doc udev/12-dm-permissions.rules
/%_lib/libdevmapper.so.1.03
/%_lib/libdevmapper-event.so.1.03
/%_lib/libdevmapper.so.1.02
/%_lib/libdevmapper-event.so.1.02
/sbin/dmsetup
/sbin/dmeventd
%_sbindir/thin_*
%_mandir/man8/dmsetup.8.gz
%_mandir/man8/dmeventd.8.gz
%_mandir/man8/thin_*.8*
%_udevrulesdir/10-dm.rules
%_udevrulesdir/13-dm-disk.rules
%_udevrulesdir/95-dm-notify.rules
%_unitdir/dm-event.socket
%_unitdir/dm-event.service
%_sbindir/cache_*
%_sbindir/era_*
%_sbindir/pdata_tools
%_mandir/man8/cache_*.8*
%_mandir/man8/era_*.8*

%package -n device-mapper-devel
Summary:        Development package for the device mapper
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Version:        %{device_mapper_version}
Release:        75.28
Requires:       device-mapper = %{device_mapper_version}

%description -n device-mapper-devel
Files needed for software development using the device mapper

%files -n device-mapper-devel
%defattr(-,root,root)
%_libdir/libdevmapper.so
%_libdir/libdevmapper-event.so
%_libdir/libdevmapper.a
%_includedir/libdevmapper*.h
%_libdir/pkgconfig/devmapper*.pc

%if %{enable_testsuite}
%package testsuite
Summary:        LVM2 Testsuite
License:        LGPL-2.0+
Group:          Development

%description testsuite
An extensive functional testsuite for LVM2.

%files testsuite
%defattr(-,root,root,-)
#%{_libdir}/lvm2-testsuite/
%{_datarootdir}/lvm2-testsuite/
%{_libexecdir}/lvm2-testsuite/
%{_bindir}/lvm2-testsuite
%endif

%changelog
* Wed Mar  1 2017 zren@suse.com
- Fix clvmd segfault on ppc64 arch (bsc#1025630)
  * bug-1025630_mem-add-extra-mem-pages-for-pthread-stack.patch
* Wed Mar  1 2017 zren@suse.com
- Fix several trivial issues about clvmd/cmorriord RAs (bsc#1023283,
  bsc#1025560)
  * deal with time values  passed down with time units
  * make correct "return code"
  * fix format issue that tab messes up spaces
* Wed Mar  1 2017 zren@suse.com
- systemd: use {local,remote}-fs-pre.target instead of
  {local,remote}-fs.target (bsc#1017034)
* Wed Mar  1 2017 zren@suse.com
- udev: Simplify special-case for md in 69-dm-lvm-metadata.rules
  (bsc#1012973)
  * add bug-1012973_Simplify-special-case-for-md-in-69-dm-lvm-metadata.patch
* Tue Dec 20 2016 gqjiang@suse.com
- Add systemd_requires to device-mapper package (bsc#1015943)
* Sat Oct  8 2016 lwang@suse.com
- spec: Add BuildRequires: pkgconfig(systemd) (bsc#997637)
- udev: Instead of using = to override SYSTEMD_WANTS, use += to add
  the pvscan service (not root cause for bsc#997637, but still better
  to add this patch)
  Add : udev-use-for-SYSTEMD_WANTS-instead-of.patch
* Wed Aug 31 2016 lwang@suse.com
- Delete the patch since it is not neccessary for the bug fix and has
  the risk to cause regression bug for thin-merge.sh (bsc#984321)
    Delete: activate-Improve-snapshot-merge-initiation.patch
    (Improve snapshot merge initiation (bsc#970943))
* Sat Aug 20 2016 lwang@suse.com
- Fix DM_ABORT_ON_INTERNAL_ERRORS env var not take effect (bsc#984321)
  Add: log-Add-DM_ABORT_ON_INTERNAL_ERRORS-lvm-override.patch
- Remove require for %%insserv_prereq %%fillup_prereq (bsc#992843)
* Fri Aug 19 2016 hare@suse.de
- 69-dm-lvm-metad.rules: Do not process rules for multipath
  devices (bsc#bsc#990538, bsc#986734)
  Add: 69-dm-lvm-metad.rules-Do-not-process-rules-for-multi.patch
- Rewrite patches to include patch header:
  * 10-dm.rules-Reset-state-variable-for-spurious-events.patch
  * device-mapper-link
  * device-mapper-type_punning.diff
  * udev_rules-update.diff
* Fri Jul 29 2016 lwang@suse.com
- Fix lvm2-{clvmd, cmirrord}.service cannot find binaries path. (bsc#991181)
  Add soft link to /usr/sbin/{clvmd, cmirrord} in spec
* Mon Jul 18 2016 lwang@suse.com
- Lvchange improve refresh by trying to deactivate snapshot thinLV
  in case it's preventing merge process. (bsc#984321)
  Add: lvchange-improve-refresh-for-merging-thin-volume.patch
* Mon Jun  6 2016 lwang@suse.com
- Modified raid10_segtype_default from "mirror" to "raid10"(bsc#982329)
* Fri May 27 2016 lwang@suse.com
- Remove lvm2-clvmd/cmirrord.service and related activation services
  from %%service_add _pre/post/preun/postun because we start clvmd
  /clmirrord and activate via pacemaker and RA. (bsc#980296)
* Mon May 23 2016 lwang@suse.com
- Fix clvmd binary not found in case that users still use RA from
  ocf:lvm2:clvm (bsc#980200)
  Add sbindir=$HA_SBIN_DIR for clvmd.ocf and cmirrord.ocf
* Mon May 16 2016 lwang@suse.com
- clvm resources do not start because can't find lvmconf (bsc#979635)
  Add soft link to /usr/sbin/lvmconf in spec
* Tue May  3 2016 lwang@suse.com
- Fix regression in auto-activation code introduced in 2.02.119
  (bsc#970943)
  Add: pvscan-restore-polling-in-autoactivation-handler.patch
- Improve snapshot merge initiation (bsc#970943)
  Add: activate-Improve-snapshot-merge-initiation.patch
  (Not needed for this bug itself but add this patch for safe)
* Tue Mar 29 2016 lwang@suse.com
- Modified spec to enable blkid-wiping with which filesystem check
  before pvcreate can function. (Fate#319908)
* Mon Mar 28 2016 lwang@suse.com
- Fix clvmd.ocf and cmirrord to remove "-d" option for cmirrod
  (bsc#971334)
- Fix clvmd.ocf to add lvmconf --enable-cluster before start daemon
  when locking_type is not 3 or use_lvmetad is 1 in setting
  (bsc#970439)
- Modify GPL-2.0 to GPL-2.0+ and LGPL-2.1 to LGPL-2.1+ to avoid
  license conflict with thin-provisioning-tools which is using GPL-3.0
* Fri Mar 11 2016 lwang@suse.com
- Fix pvchange returning with exit code 5 if another volume group
  which is not related to the PVs is exported. (bsc#969310)
  Add: pvchange-pvresize-move-exported-VG-check.patch
* Mon Feb 29 2016 lwang@suse.com
- pvcreate: remove recent warning message (bsc#966183)
  Add: preate-remove-recent-warning-message.patch
- Change locking_dir from "/var/lock/lvm" back to "/run/lvm/lock"
  (bsc#963427)
- pvcreate: enchance the error message to be more informative (bsc#960744)
  Add: pvcreate-enhance-the-error-message.patch
* Tue Dec 29 2015 lwang@suse.com
- Add 'Also=lvm2-lvmetad.socket' in '[Install]' section of lvm2-lvmetad.
  service to remove lvm2-lvmetad.socket when disable lvm2-lvmetad.service.
  (bsc#960044)
  Add: lvm2-lvmetad.service-add-Also-lvm2-lvmetad.socket.patch
* Fri Nov 20 2015 lwang@suse.com
- lvmcache: Remove verbose msg when rescanning devices.(bsc#955529)
  add: lvmcache-Remove-verbose-msg-when-rescanning-dev.patch
- Do not output error message inside retry loops to avoid noisy error
  message being output inside retry loops in case of remove failure
  because device busy. (bsc#940298)
  add: libdm-iface-not-output-error-message-inside-retry-loop.patch
* Thu Nov 12 2015 lzhong@suse.com
- Merge the configuration item "debug_class" into one line (bsc#954744).
* Wed Oct 28 2015 lwang@suse.com
- Only not support unpartitioned DASD device with CDL formatted.
  (bnc#948859#946217)
  add: pvcreate-don-t-support-unpartitioned-DASD-devices-with-CDL-formatted.patch
* Tue Oct 20 2015 lzhong@suse.com
- Change $OCF_RESKEY_daemon_options from -d2 to -d0(bnc#949933)
* Wed Oct 14 2015 lzhong@suse.com
- add a new test package named lvm2-testsuite(bnc#950089)
    + lvm2-testsuite.patch
  Currently this new package is not enabled by default. Please set
  enable_testsuite to 1 to turn it on in the spec file.
* Tue Sep 22 2015 lwang@suse.com
- Fix boot failure when upgrading from sle12gm to sle12sp1 due to
  lvm2-lvmetad.socket not enabled as expected. (bnc#945095)
  Add "Requires(pre/post): systemd-presets-branding to spec.
* Wed Sep  9 2015 lwang@suse.com
-Fix segfault when extending an LV with a smaller number of
  stripes than originally used. (bnc#942888)
  add: alloc-Fix-lvextend-failure-when-varying-stripes.patch
    fix-build-error-caused-by-commit-b93b8537.patch
-Remove unrecognazed RemoveOnStop from lvm2-lvmetad.socket(bnc#943569)
  add: remove-unrecognized-RemoveOnStop-from-lvm2-lvmetad-socket.patch
* Mon Aug 24 2015 lwang@suse.com
- Fix boot failed due to segfault at libc (bnc#942755)
  add: lvmetad.c-ignore-lvmetad-global-handle-on-disconnect.patch
* Fri Aug 14 2015 lwang@suse.com
- Enable lvmetad by default (Fate#318752)
* Thu Aug  6 2015 lwang@suse.com
- Update thin-provisioning tools to 0.5.3
  * Fix thin_dump segment fault. (bnc#940808)
  * Fix bug where the tools would crash if given a very large
    metadata device to restore to.
  * - thin_delta, thin_trim
  * --clear-needs-check flag for cache_check
  * space map checking for thin check
- Drop unnecessary lvm2-do-not-strip-pdata_tools.patch
* Thu Aug  6 2015 lwang@suse.com
- fix spec to change /sbin/thin-check to %%{_sbindir}/thin-check.
  (bnc#940754)
* Thu Jul  9 2015 lwang@suse.com
- dmeventd: fix dso_name compare error. dso_name is thought as not
  empty and doesn't create monitor thread. (bnc#935623)
  add: dmeventd-fix-dso-name-wrong-compare.patch
* Thu Jun  4 2015 lwang@suse.com
- fsadm: add support for btrfs.(FATE#318413)
  add: fsadm-add-support-for-btrfs.patch
- lvscan gives no output in silent mode, point out in manpage.
  add: manpage-lvscan-fix.patch.(bnc#841060)
* Thu Jun  4 2015 lwang@suse.com
- Updated to lvm2-2.02.120 device-mapper-1.02.97 thin_provisioning_tools-0.4.2
  (FATE#318255)
  - Eliminated 28 patches in original lvm2 package:
  pipe_buff-definition.diff: don't know why necessary
  handle_extended_devt.diff: not need(bnc#525060 not reproduce even without this patch)
  support-drbd-filter.diff: source to patch not found
  lvm-path.patch: not needed, upstream fixed hardcode. add link in spec %%post
  suppress_locking_failer_message.patch: no doc as to why suppress warning
  add_scm_support.patch: definition device_info_t _device_info is no longer exist
  (The following 22 patches eliminated because they are from upstream:)
  man_page_sectors.diff
  make_raid1_default.diff
  remove-fedora-systemd.patch
  lvmetad-Init-lazily-to-avoid-socket-access-on-config.patch
  do_not_read_from_mirrors_have_failed_devices.diff
  avoid_reading_failed_dev_in_mirrored_log.diff
  mirrored_log_fixed_when_double_fault_occurs.diff
  device_is_usable_mem_leak.diff
  clmvd-fix-decriptor-leak-on-restart.patch
  clvmd-Fix-node-up-down-handing-in-corosync-module.patch
  clvmd-Avoid-a-3-way-deadlock-in-dead-client-cleanup.patch
  0001-clvmd-avoid-logging-in-signal-handler.patch
  0001-RAID-Make-RAID-4-5-6-display-sync-status-under-headi.patch
  clvmd-fix-debugging-level-set-in-clvmd_set_debug-function.patch
  toolcontext-Only-reopen-stdin-if-readable.patch
  systemd-lvm2-activation-generator-report-only-error.patch
  systemd-use-umask-022-for-generated-systemd-units-by.patch
  remove-quote-in-lvm2-monitor.patch
  retry-cleanup-deactivation.patch
  display-skipped-prompt-in-silent-mode.patch
  cmirrord-fix-s390-endian-issue.patch
  dab3ebce-devices-Do-not-support-unpartitioned-DASD.patch
  - Eliminated 6 patches in original device-mapper package:
  bug-479104_device-mapper-dmsetup-deps-export.patch:merged with device-mapper-dmsetup-export.patch
  udev_sync-cookie_set-1-on-each-dm_task_set_cookie-ca.patch: already included in upstream
  increase-minor-version.diff: not needed
  segault_for_truncated_string_token.patch: upstream
  s390-sectorsize4096.patch: upstream
  add_integrate_flush_flag.patch: included in cmirrord_improvment_performance.patch
* Thu May 28 2015 lzhong@suse.com
- 10-dm.rules: Reset state variables for spurious events (bsc#932300)
  10-dm.rules-Reset-state-variable-for-spurious-events.patch
* Tue May 19 2015 jeffm@suse.com
- Merged lvm2 and device-mapper packages since they are built
  from the same source archive.  No code changes. Udev rules
  merged where there were conflicts. (FATE#318255)
* Tue May 19 2015 jeffm@suse.com
- Added patch tags and reordered patches to apply upstream patches
  first.  No code changes.
* Mon May 18 2015 lzhong@suse.com
-13-dm-disk.rules: Import ID_FS_XXX variables from udev
  database(bnc#909358)
  If the disk is unavailable we need to import the existing ID_FS_XXX
  variables from the database, otherwise the filesystem UUID won't
  be set and the by-uuid symlink will disappear, leading to
  intermittent boot failures
    Import-ID_FS_XXX-variables-bnc909358.patch
* Thu Mar 19 2015 lzhong@suse.com
- add patches for multipath support(bsc#922905)
    udev-Check-for-DM_NR_VALID_PATHS.patch
* Wed Feb  4 2015 lwang@suse.com
- LVM2 does not support unpartitioned DASD device which has special
  format in the first 2 tracks and will siliently discards LVM2 lable
  information written to it when pvcreate. (bsc#894202)
  Add: dab3ebce-devices-Do-not-support-unpartitioned-DASD.patch
- To enable lvm2-lvmetad.socket needs to add it to %%service_add_pre/post
  (bsc#908791)
- Set silent default to 0 to avoid some commands have no output
  and to be same with upstream. (bsc#888798,bsc#912499)
* Fri Sep  5 2014 lwang@suse.com
- cmirrord has endian issue which cause cmirrord start fail on s390
  patch: cmirrord-fix-s390-endian-issue.patch(bnc#890452,bnc#893684)
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Aug 20 2014 lwang@suse.com
- Since decisions in the silent mode may not be always obvious,
  print skipped prompt with answer 'n'.  (bnc#892444)
  patch: display-skipped-prompt-in-silent-mode.patch
* Wed Aug 20 2014 lwang@suse.com
- Enable 'retry' deactivation also in 'cleanup' phase.
  It shouldn't be mostly needed - however udev now produces
  more and more completelny non-synchronizable device opens,
  so even for orphan devices we can't easily predict where
  udevd opens devices.
  So it's more preferable here to log error about device being open
  and retry clean, but let the command proceed.
  patch: retry-cleanup-deactivation.patch (bnc#892319)
* Fri Jul  4 2014 dmzhang@suse.com
- bnc#885632, set multipath_componnet_detection = 1 per default
* Fri Jun 13 2014 hare@suse.de
- Generate all symlinks even for multipath events (bnc#875233)
  patch: udev-Check-for-DM_NR_VALID_PATHS.patch
* Thu May 29 2014 dmzhang@suse.com
- bnc#878930, systemd is putting out an erroneous message about lvm2-monitor.service
  patch: remove-quote-in-lvm2-monitor.patch
* Wed May 28 2014 lwang@suse.com
- fix lvm2-activation{,-early}.service is marked world-inaccessible (bnc#878481)
  add systemd-use-umask-022-for-generated-systemd-units-by.patch
- add comment to lvm.conf to inform user to start lvm2-lvmetad.socket
  if it is not started in case of use_lvmetad = 1 (bnc#878473)
* Wed May 21 2014 lwang@suse.com
- Switch from mkinitrd to dracut
  - Dracut already has a lvm module and takes care that the right stuff is
    include into initrd, therefore remove:
  - mkinitrd-lvm2-boot.sh
  - mkinitrd-lvm2-setup.sh
    mkinitrd scripts from sources
  - Add dracut macros in %%post and %%posttrans to ensure initrd recreation
- Remove unneeded comments in .spec file
- Do not compile in DATE and TIME to avoid build unneeded retriggering in obs
  Add: cmirrord_remove_date_time_from_compilation.patch-
* Wed May 21 2014 lwang@suse.com
- bnc#878121, modify clvmd.ocf start debug level -d2 to d0
* Tue May 20 2014 lwang@suse.com
-- Added: clvmd-fix-debugging-level-set-in-clvmd_set_debug-function.patch
  This patch is missed in sle12, added from sle11sp3
  Fix debugging level set in clvmd_set_debug by using the correct
  variable (bnc#785467),change default -d0 to -d2
* Mon Apr 28 2014 lwang@suse.com
-bnc#871176, 0001-RAID-Make-RAID-4-5-6-display-sync-status-under-headi.patch
  The heading 'Copy%%' is is a bit awkward to use 'Copy%%' for RAID 4/5/6,
  however - 'Sync%%' would be more appropriate.
* Thu Apr 24 2014 dmzhang@suse.com
- bnc#874957 ,missing braces in use-mirrortype-asdefault-whenclvmdrunning.patch
  refresh the patch
* Tue Apr 15 2014 lmb@suse.com
- Versioning for the lvm2-cmirrord dependencies
* Mon Apr 14 2014 dmzhang@suse.com
- bnc#870598, change lockdir to /run/lvm/lock
  modify lvm.conf
  bnc#854092, backport patches to fix 'nohup lvm' crash
  patch:0001-toolcontext-Only-reopen-stdin-if-readable.patch
  bnc#870824, defaut the mirrortype to mirror when clvmd is running
  patch:use-mirrortype-asdefault-whenclvmdrunning.patch
  bnc#859824, get rid of the annoying message 'LVM activation generator successfully completed'
  patch:systemd-lvm2-activation-generator-report-only-error.patch
  bnc#837538, fix closedown of clvmd
  patch:fix-closedown-before-thread-finish.patch
* Fri Apr 11 2014 lwang@suse.com
- bnc#862403, modify lvm.conf to add filter to exclude floppy and cdrom
* Fri Apr  4 2014 lmb@suse.com
- lvm2-cmirrord replaces cmirrord on update from SLE HA 11
  (bnc#872122)
* Tue Mar 18 2014 dmzhang@suse.com
- backport more patches from slesp3(bnc#831518)
  scm support:
    add_scm_support.patch
  mirrored log fix:
    do_not_read_from_mirrors_have_failed_devices.diff
    avoid_reading_failed_dev_in_mirrored_log.diff
    mirrored_log_fixed_when_double_fault_occurs.diff
    device_is_usable_mem_leak.diff
  clvmd:
    clmvd-fix-decriptor-leak-on-restart.patch
    clvmd-Avoid-a-3-way-deadlock-in-dead-client-cleanup.patch
    clvmd-Fix-node-up-down-handing-in-corosync-module.patch
    0001-clvmd-avoid-logging-in-signal-handler.patch
  fate#314367, missing patch
    lvconvert-cluster-mirrored-disk-failed.patch
  other fix:
    pvmove_support_clustered_vg.diff
    suppress_format1_size_warning.diff
    display-dm-name-for-lv-name.diff
* Fri Feb 21 2014 dmzhang@suse.com
- further fix for bnc#862076,bnc#864023
  add lvmetad-Init-lazily-to-avoid-socket-access-on-config.patch
  fix 'systemctl daemon-reload' hang after setting use_lvmetad in lvm.conf
* Wed Feb 19 2014 dmzhang@suse.com
- drop autoactivate-lvmetad-with-generator.patch;
  bnc#862076, the patch does not work
  disable lvmetad in lvm.conf to fix it
* Thu Feb 13 2014 dmzhang@suse.com
- fate#315092, improve performance of cluster mirror
* Wed Feb 12 2014 arvidjaar@gmail.com
- add autoactivate-lvmetad-with-generator.patch - if use_lvmetad=1,
  automatically activate lvm2-lvmetad.socket to ensure lvmetad is
  started when required (bnc#862076)
* Wed Jan 22 2014 henrik.kuhn@origenis.de
- added a lvm2-devel package definition
* Mon Jan  6 2014 dmzhang@suse.com
- add csm_convert to lvm2-clvm package(bnc#854076)
- system fails to boot due to missing /usr/sbin/lvm(bnc#837954)
- lvm2 systemd incorrectly uses dependencies on Fedora services(bnc#851741)
- set use_lvmetad = 1 as default of lvm.conf(bnc#854413)
- drop patch dont_ignore_tmp_device_file.diff
- backport patches from sle11sp3
  fate#314367,cluster_support_mirrord_log.diff
  fate#312248,make-mirror-legs-on-different-tag-pvs.patch
  improve-mirror-legs-on-different-tag-pvs.patch
- set default mirror to md_raid1 insdead of dm_mirror for better performance
- enable lvm2-lvmetad.socket by default
* Sun Oct 27 2013 ohering@suse.de
- Remove /etc/sysconfig/lvm to avoid errors during mkinitrd run
  LVM_VGS_ACTIVATED_ON_BOOT is not handled anymore with systemd
- Remove fillup and insserv from PreReq
* Mon Oct 21 2013 dmzhang@suse.com
- bnc#779965, use export before %%configure in spec
* Wed Sep 11 2013 fcrozat@suse.com
- Add lvm-path.patch: fix lvm binary path in systemd generator.
- Use %%_tmpfilesdir macro for tmpfiles directory.
* Sun Sep  8 2013 crrodriguez@opensuse.org
- Set all "run" directories relative to /run not just the "lock"
  location
- Install /usr/lib/tmpfiles.d/lvm2.conf as required to ensure
  such runtime directories are _always_ there.
* Wed Aug 28 2013 meissner@suse.com
- replace BuildRequires: systemd by pkgconfig(udev) again
  to avoid cycles.
* Tue Aug 20 2013 dmzhang@suse.com
- add systemd support to lvm2 package
  split device-mapper to another package.
* Tue Jul 16 2013 ohering@suse.de
- Remove usage of absolute paths in mkinitrd scripts
* Tue Jul 16 2013 ohering@suse.de
- Fix parsing lvdisplay -c output with more than 10 volumes in
  mkinitrd-lvm2-setup.sh (bnc#826727)
* Mon Apr 22 2013 cfarrell@suse.com
- license update: GPL-2.0 and LGPL-2.1
  Presence of multiple files (both GPL and LGPL) with "only" licenses
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Feb 15 2013 rmilasan@suse.com
- Move all udev releated files in the appropriate udev directory.
* Wed Nov 28 2012 rmilasan@suse.com
- udev_sync-cookie_set-1-on-each-dm_task_set_cookie-ca.patch:
  cookie_set=1 on each dm_task_set_cookie call (bnc#788882)
* Mon Nov 12 2012 seife+obs@b1-systems.com
- fix 10-dm.rules (bnc#789021)
- port dmsetup export patch to new LVM code (bnc#789019,bnc#789020)
* Mon Nov  5 2012 hrvoje.senjan@gmail.com
- Now also fix devmapper-setup
* Mon Nov  5 2012 hrvoje.senjan@gmail.com
- Adapt mkinitrd scripts to new udev locataion
* Sun Nov  4 2012 crrodriguez@opensuse.org
- Fix booting ... place udev rules in the proper location..
* Thu Oct 18 2012 hrvoje.senjan@gmail.com
- Change the default locking dir to reflect the change in filesystem package
* Wed Oct 17 2012 nfbrown@suse.com
- lvm2.spec: merge rules for device-mapper and
  lvm2-clvm packages, so there is only one
  spec file and all packages are built consistently.
* Tue Oct 16 2012 coolo@suse.com
- build against the minimal udev to avoid cycles
- the sysvinit requires are no longer necessary
* Tue Oct 16 2012 nfbrown@suse.com
- Upgrade to LVM2-2-02-98.  Improvements include
  improved interaction with udev and systemd,
  improved dmraid support, and new command
  "blkdeactivate".
* Thu Sep 27 2012 nfbrown@suse.com
- lvm2.spec: make sure MODPROBE_CMD is set properly
  when configure is run.  Without it, modules are
  not auto-loaded.  (bnc#779965)
* Fri Apr 20 2012 rmilasan@suse.com
- Run update of initrd at %%post and %%postun.
  We need this to make sure initrd reflects the updates.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Fri May 27 2011 lnussel@suse.de
- don't unconditionally enable boot.lvm by default. yast takes care
  of enabling the script when creating lvm volumes.
- don't hard require boot.device-mapper in boot.dmraid. dm-mod is
  autoloaded when accessing /dev/mapper/control anyways.
* Thu Mar 10 2011 coolo@novell.com
- prereq sysvinit(boot.device-mapper) to fix build
* Tue Feb 15 2011 xwhu@novell.com
- Update to LVM 2.02.84
  - Fix handling of simultaneous mirror image and mirrored log
    image failure.
  - Fix vgremove to allow removal of VG with missing PVs
  - Remove log directly if all mirror images of a mirrored log fail
  - Fix potential for corruption during cluster mirror device
    failure
  - Allow internal suspend and resume of origin without its
    snapshots
  - Allow exclusive activation of snapshots in a cluster
* Thu Nov 11 2010 coolo@novell.com
- own parent directories for device-mapper files
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Fri Jul 16 2010 xwhu@novell.com
- bnc#556177, undefined symbol error while loading dmevent so.
* Wed Jun 23 2010 xwhu@novell.com
- Update to LVM.2.02.67
  - Require partial option in lvchange --refresh for partial LVs
  - Add replicators' LVs to dtree for activation
  - Add lvm2app interfaces to lookup a vgname from a pvid and pvname
  - Fix memory leak for invalid regex pattern input
  - Disallow the direct removal of a merging snapshot
  - Fix lvconvert error message when existing mirrored LV is not found
  - Add LVM_SUPPRESS_LOCKING_FAILURE_MESSAGES environment variable
  - Improve snapshot merge metadata import validation
* Tue Jun  1 2010 xwhu@novell.com
- Specify udev_sync and udev_rules in /etc/lvm/lvm.conf
* Fri May 21 2010 xwhu@novell.com
- Fix mkinitrd-lvm2 to use udev rules for lvm2
* Mon Apr 26 2010 ro@suse.de
- fix lvm2-clvm specfile so that patches apply
* Sat Apr  3 2010 xwhu@novell.com
- Upgrade to LVM2 2.02.58
  - Rename liblvm.so to liblvm2app.so
  - Introduce lvconvert --use_policies
  - Add readonly locking type to replace implementation of
  - -ignorelockingfailure
  - Add liblvm APIs to implement creation and deletion of VGs
  - Add activation/udev_sync to lvm.conf
  - Enable dmeventd monitoring section of config file by default
  - Add --pvmetadatacopies for pvcreate, vgcreate, vgextend,
    vgconvert.
* Sun Nov 29 2009 xwhu@novell.com
- Link liblvm2cmd.so to libdevmapper-event.so (bnc#556177)
* Sun Nov 15 2009 meissner@suse.de
- quilt refreshed all patches.
* Mon Oct 12 2009 xwhu@novell.com
- make $tmp_mnt/etc/sysconfig before copying file into (bnc#525237)
* Wed Sep 23 2009 xwhu@novell.com
- Add -lvm2- infix to mkinitrd scripts
- collect_lvm reads /etc/sysconfig/lvm (bnc#523944)
* Fri Aug 28 2009 xwhu@novell.com
- Support extended dev with major 259
* Fri Jun 26 2009 xwhu@suse.de
- bnc#510058, typo in dont_ignore_tmp_device_file.diff, which hangs
  mkinitrd
* Mon May 25 2009 xwhu@suse.de
- Cleanup scripts for mkinitrd, so that udev can activate root LV.
* Tue Apr 28 2009 xwhu@suse.de
- Upgrade to LVM2 2.02.45
  Avoid scanning empty metadata areas for VG names
  Pass --test from lvresize to fsadm as --dry-run.
  Remove duplicate cpg_initialize from clvmd startup.
  Add option to /etc/sysconfig/cluster to select cluster type for clvmd.
  Remove external dependency on the 'cut' command from fsadm.
  Fix pvs segfault when pv mda attributes requested for not available PV.
  Fix lvresize size conversion for fsadm when block size is not 1K.
  Add pv_mda_size to pvs and vg_mda_size to vgs.
  Add "--refresh" functionality to vgchange and vgmknodes.
  Fix vgrename using UUID if there are VGs with identical names.
  Fix segfault when invalid field given in reporting commands.
  Merge device-mapper into the lvm2 tree.
  Exit with non-zero status from vgdisplay if couldn't show any requested VG.
  Fix snapshot monitoring library to not cancel monitoring invalid snapshot.
  Fix conversion of md chunk size into sectors.
  Fix misleading error message when there are no allocatable extents in VG.
  Fix handling of PVs which reappeared with old metadata version.
  Fix mirror DSO to call vgreduce with proper parameters.
  Fix validation of --minor and --major in lvcreate to require -My always.
  Fix release: clvmd build, vgreduce consolidate & tests, /dev/ioerror warning.
* Tue Mar 31 2009 xwhu@suse.de
- Handle the case that drbd virtual device has the same PV uuid
  with the underlining physical device.
* Thu Mar 26 2009 xwhu@suse.de
- Do not filter out tmp device file(bnc#485572)
- Do not try to activate VG when all paths are down already(bnc#479104)
* Thu Mar 26 2009 xwhu@suse.de
- Split CLVMD as a independent package
* Tue Mar 24 2009 xwhu@suse.de
- Fix for bnc#486952
  use "killproc -INT" instead of "killproc"
  handle signal in the main loop thread only
* Thu Feb 26 2009 xwhu@suse.de
- add daemon_options parameter to clvmd.ocf
- check EUNLOCK for dlm_ls_unlock_wait
* Thu Feb 26 2009 xwhu@suse.de
- bnc#479422, check both lksb.sb_status and status.
* Fri Feb 20 2009 xwhu@suse.de
- simplify patch of dlm lock to clvmd
* Fri Feb 20 2009 xwhu@suse.de
- bnc#476861, clvmd.ocf doesn't report the correct status when
  kill -9 doesn't terminate the process
* Thu Jan 22 2009 xwhu@suse.de
- bnc#464851, use dlm instead of openais lck
* Wed Jan 21 2009 ro@suse.de
- do not require a specific package release from subpackage
  (bnc#467704)
* Thu Dec  4 2008 xwhu@suse.de
- Add OCF script for clvmd
* Wed Nov 12 2008 xwhu@suse.de
- bnc#443677. dmeventd DSOs are linked against liblvm2cmd
* Thu Oct  9 2008 xwhu@suse.de
- bnc#432782. Remove vol_id in 64-lvm2.rules.
* Mon Sep 29 2008 ro@suse.de
- buildreq: replace openais-devel by libopenais-devel
* Wed Sep 24 2008 ro@suse.de
- change "udevsettle" to "udevadm settle"
* Sat Sep 13 2008 xwhu@novell.com
- added missing directories to filelist
* Wed Sep 10 2008 xwhu@novell.com
- Upgrade to 2.0.39
  Fix up cache for PVs without mdas after consistent VG metadata is processed.
  Update validation of safe mirror log type conversions in lvconvert.
  Fix lvconvert to disallow snapshot and mirror combinations.
  Fix reporting of LV fields alongside unallocated PV segments.
  Add --unquoted and --rows to reporting tools.
  Avoid undefined return value after _memlock manipulation in lvm2_run.
  Avoid link failure if configured without --enable-cmdlib or --enable-readline.
  Make clvmd return at once if other nodes down in a gulm or openais cluster.
  Fix and improve readahead 'auto' calculation for stripe_size.
  Fix lvchange output for -r auto setting if auto is already set.
  Fix ambiguous use of identifier error_message_produced.
  Fix add_mirror_images not to dereference uninitialized log_lv upon failure.
  Don't call openlog for every debug line output by clvmd.
  Add --force to lvextend and lvresize.
  Fix vgchange to not activate mirror leg and log volumes directly.
  Fix test directory clean up in make distclean.
- pvcreate/pvremove/pvchange will create symlinks in /dev/disk/by-id/
  to the device file
* Wed Sep  3 2008 hare@suse.de
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Tue Sep  2 2008 hare@suse.de
- Fix initrd scripts if no 'root=' parameter is given
  (bnc#421546)
* Mon Aug 25 2008 aj@suse.de
- Provide and obsolete evms.
* Mon Aug 25 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Fri Aug 22 2008 xwhu@suse.de
- Remove the -p option for fillup_and_insserv
* Wed Aug 13 2008 xwhu@suse.de
- Add Should-Stop to boot.lvm
* Thu Jul 31 2008 xwhu@suse.de
- repack LVM2.2.02.38.tar.bz2 into bz2 format
* Wed Jul 23 2008 hare@suse.de
- Include mkinitrd scriptlets.
* Fri Jun 27 2008 xwhu@suse.de
- update to 2.02.38
  Fix tracking of validity of PVs with no mdas in lvmcache.
  Fix return values for reporting commands when run with no PVs, LVs, or VGs.
  Fix free_count when reading pool metadata.
  Fix segfault when using pvcreate on a device containing pool metadata.
  Fix segfault after _free_vginfo by remembering to remove vginfo from list.
  Fix setpriority error message to signed int.
  Fix uninitialised mutex in clvmd if all daemons are not running at startup.
  Fix fsadm.sh to work with older blockdev, blkid & readlink binaries.
  Fix lvresize to pass new size to fsadm when extending device.
  Fix nodes list in clvmd-openais, and allow for broadcast messages.
  Fix vgsplit internal counting of snapshot LVs.
  Fix vgmerge snapshot_count when source VG contains snapshots.
  Fix internal LV counter when a snapshot is removed.
  Fix metadata corruption writing lvm1-formatted metadata with snapshots.
  Fix lvconvert -m0 allocatable space check.
  Fix vgdisplay 'Cur LV' field to match lvdisplay output.
  Fix lv_count report field to exclude hidden LVs.
  Fix vgsplit to only move hidden 'snapshotN' LVs when necessary.
  Fix vgreduce to use vg_split_mdas to check sufficient mdas remain.
  Fix orphan VG name used for format_pool.
  Fix output if overriding command_names on cmdline.
  Fix vgsplit locking of new VG (2.02.30).
  Fix redundant lvresize message if vg doesn't exist.
  Fix another allocation bug with clvmd and large node IDs.
  Fix uninitialised variable in clvmd that could cause odd hangs.
* Mon May  5 2008 aj@suse.de
- Fix requires of clvm.
* Wed Apr 30 2008 hare@suse.de
- Fixup build errors
* Wed Apr 30 2008 xwhu@suse.de
- Cleanup clvmd code on openais stack to make it work
- Split clvmd into a separate package (bnc#384708)
* Wed Apr 23 2008 xwhu@suse.de
- Change async lock primitives to sync
* Wed Apr 23 2008 xwhu@suse.de
- Fix build aginst beta
  definition of PIPE_BUF is missing
* Tue Apr 22 2008 xwhu@suse.de
- Enable CLVM support in LVM2
* Wed Feb 20 2008 fehr@suse.de
- allow large minor number on command line with option --minor
  (bnc#362960)
* Wed Feb 13 2008 fehr@suse.de
- update to new version 2.02.33
  Fix mirror log name construction during lvconvert. (2.02.30)
  Make monitor_dev_for_events recurse through the stack of LVs.
  Clean up some more compiler warnings.
* Thu Feb  7 2008 hare@suse.de
- Enable dmeventd (FATE#303381)
* Thu Jan 31 2008 fehr@suse.de
- update to new version 2.02.32
  Fix two check_lv_segments error messages to show whole segment
  Refactor mirror log attachment code
  Fix pvs, vgs, lvs error exit status on some error paths
  Avoid readahead error message with default setting of lvcreate -M1
  Set default readahead to twice maximium stripe size
  Reinstate VG extent size and stripe size defaults (halved)
  Change vgsplit -l (for unimplemented --list) into --maxlogicalvolumes
  Fix process_all_pvs to detect non-orphans with no MDAs correctly
  Don't use block_on_error with mirror targets version 1.12 and above
  Update vgsplit to accept vgcreate options when new VG is destination
  Update vgsplit to accept existing VG as destination
  lvconvert waits for completion of initial sync by default
  Refactor vgcreate for parameter validation and add tests
  Add new convert_lv field to lvs output
  Print warning when lvm tools are running as non-root
  Prevent pvcreate from overwriting MDA-less PVs belonging to active VGs
  Fix a segfault if using pvs with --all argument
  Update --uuid argument description in man pages
  Fix vgreduce PV list processing not to process every PV in the VG
  Extend lvconvert to use polldaemon
  Add support for stacked mirrors
  Major restructuring of pvmove and lvconvert layer manipulation code
* Mon Dec 10 2007 fehr@suse.de
- update to new version 2.02.29
  Accept sizes with --readahead argument.
  Store size arguments as sectors internally.
  Attempt to remove incomplete LVs with lvcreate zeroing/activation problems.
  Add read_ahead activation code.
  Extend readahead arg to accept "auto" and "none".
  Prevent lvconvert -s from using same LV as origin and snapshot.
  Fix human-readable output of odd numbers of sectors.
  Show 'not usable' space when PV is too large for device in pvdisplay.
  Ignore and fix up any excessive device size found in metadata.
  Detect md superblocks version 1.0, 1.1 and 1.2.
  Handle new sysfs subsystem/block/devices directory structure.
  Add %%PVS extents option to lvresize, lvextend, and lvcreate.
  Modify lvremove to prompt for removal if LV active on other cluster nodes.
  Add '-f' to vgremove to force removal of VG even if LVs exist.
* Thu Nov 22 2007 fehr@suse.de
- adapt man page for pvdisplay to program (#342862)
- fix spec file to detect path to modprobe binary (#331968)
* Thu Nov 22 2007 fehr@suse.de
- update to new version 2.02.28
  Fix inconsistent licence notices: executables are GPLv2; libraries LGPLv2.1.
  Add support for renaming mirrored LVs.
  Add --mirrorlog argument to specify log type for mirrors.
  Fix lvdisplay man page to say LV size is reported in sectors, not KB.
  Fix snapshot cow area deactivation if origin is not active.
  Add vg_mda_count and pv_mda_count columns to reports.
  Handle vgsplit of an entire VG as a vgrename.
  Print warnings to stderr instead of stdout.
  Update vgcfgrestore man page.
  Allow keyboard interrupt during user prompts when appropriate.
  Add -f to vgcfgrestore to list metadata backup files.
  Add pvdisplay --maps implementation.
  Remove unsupported LVM1 options from vgcfgrestore man page.
  Update vgcfgrestore man page to show mandatory VG name.
  Update vgrename man page to include UUID and be consistent with lvrename.
* Mon May  7 2007 fehr@suse.de
- update to new version 2.02.25
  Add devices/preferred_names config regex list for displayed device names
  Update pvck to include text metadata area and record detection
  Fix creation and conversion of mirrors with tags
  Fix vgsplit for lvm1 format (set and validate VG name in PVs metadata)
  Split metadata areas in vgsplit properly
  Fix vgremove to require at least one vg argument
  Fix reading of striped LVs in LVM1 format
  Fix vgsplit to handle mirrors
  Fix md signature check to handle both endiannesses
  Add devices/ignore_suspended_devices to ignore suspended dm devices
* Tue Feb 20 2007 fehr@suse.de
- add boot.dmraid to Should-Start in boot.lvm2
* Sun Feb 11 2007 ro@suse.de
- fix build as non-root and use DESTDIR
* Mon Jan  8 2007 fehr@suse.de
- fix buggy pointer arithmetic (#232117)
* Mon Dec 18 2006 fehr@suse.de
- update to new version 2.02.17
  Add missing pvremove error message when device doesn't exist.
  When lvconvert allocates a mirror log, respect parallel area constraints.
  Use loop to iterate through the now-ordered policy list in _allocate().
  Check for failure to allocate just the mirror log.
  Introduce calc_area_multiple().
  Support mirror log allocation when there is only one PV: area_count now 0.
  Fix detection of smallest area in _alloc_parallel_area() for cling policy.
  Add manpage entry for clvmd -T
  Fix gulm operation of clvmd, including a hang when doing lvchange -aey
  Fix hang in clvmd if a pre-command failed.
* Wed Dec  6 2006 fehr@suse.de
- update to new version 2.02.16
  Fix VG clustered read locks to use PR not CR.
  Adjust some alignments for ia64/sparc.
  Fix mirror segment removal to use temporary error segment.
  Add -T (startup timeout) switch to clvmd.
  Install lvmdump by default.
  Fix check for snapshot module when activating snapshot.
  Fix pvremove error path for case when PV is in use.
  Warn if certain duplicate config file entries are seen.
  Fix --autobackup argument which could never disable backups.
  Fix a label_verify error path.
  Fix adjusted_mirror_region_size() to handle 64-bit size.
  Add some missing bounds checks on 32-bit extent counters.
  Add Petabyte and Exabyte support.
  Fix lvcreate error message when 0 extents requested.
  lvremove man page: volumes must be cluster inactive before being removed.
  Protect .cache manipulations with fcntl locking.
  Change .cache timestamp comparisons to use ctime.
  Fix mirror log LV writing to set all bits in whole LV.
  Fix high-level free space check for partial allocations.
* Mon Oct 30 2006 fehr@suse.de
- update to new version 2.02.13 to finally fix bug #178321
  Add couple of missing files to tools/Makefile CLEAN_TARGETS.
  When adding snapshot leave cow LV mapped device active after zeroing.
  Fix a clvmd debug message.
  Add dev_flush() to set_lv().
  Add lvchange --resync.
  Perform high-level free space check before each allocation attempt.
  Don't allow a node to remove an LV that's exclusively active on anther node.
  Cope if same PV is included more than once in cmdline PE range list.
  Set PV size to current device size if it is found to be zero.
  Add segment parameter to target_present functions.
* Tue Oct 17 2006 fehr@suse.de
- update to new version 2.02.12
  Fix pvdisplay to use vg_read() for non-orphans.
  Fall back to internal locking if external locking lib is missing or fails.
  Retain activation state after changing LV minor number with --force.
  Propagate clustered flag in vgsplit and require resizeable flag.
  Add clvmd function to return the cluster name. not used by LVM yet.
  Add cling allocation policy.
  Change _check_contiguous() to use _for_each_pv().
  Extend _for_each_pv() to allow termination without error.
  Abstract _is_contiguous().
  Remove duplicated pv arg from _check_contiguous().
  Accept regionsize with lvconvert.
  Add report columns with underscore before field names ending 'size'.
  Correct regionsize default on lvcreate man page (MB).
  Fix clvmd bug that could cause it to die when a node with a long name crashed
  Add device size to text metadata.
  Fix format_text mda_setup pv->size and pv_setup pe_count calculations.
  Fix _for_each_pv() for mirror with core log.
  Add lvm_dump.sh script to create a tarball of debugging info from a system.
  Capture error messages in clvmd and pass them back to the user.
  Remove unused #defines from filter-md.c.
  Make clvmd restart init script wait until clvmd has died before starting it.
  Add -R to clvmd which tells running clvmds to reload their device cache.
  Add LV column to reports listing kernel modules needed for activation.
  Show available fields if report given invalid field. (e.g. lvs -o list)
  Add timestamp functions with --disable-realtime configure option.
  Add %%VG, %%LV and %%FREE suffices to lvcreate/lvresize --extents arg.
  Fix two potential NULL pointer derefs in error cases in vg_read().
  Separate --enable-cluster from locking lib options in lvmconf.sh.
  Add a missing comma in lvcreate man page.
* Wed Sep 20 2006 fehr@suse.de
- update to new version 2.02.10
  Fix lvconvert mirror change case detection logic.
  Fix mirror log detachment so it correctly becomes a standalone LV.
  Extend _check_contiguous() to detect single-area LVs.
  Include mirror log (untested) in _for_each_pv() processing.
  Use MIRROR_LOG_SIZE constant.
  Remove struct seg_pvs from _for_each_pv() to generalise.
  Avoid adding duplicates to list of parallel PVs to avoid.
  Fix several incorrect comparisons in parallel area avoidance code.
  Fix segment lengths when flattening existing parallel areas.
  Log existing parallel areas prior to allocation.
  Fix mirror log creation when activation disabled.
  Don't attempt automatic recovery without proper locking.
  When using local file locking, skip clustered VGs.
  Add fallback_to_clustered_locking and fallback_to_local_locking parameters.
  lvm.static uses built-in cluster locking instead of external locking.
  Don't attempt to load shared libraries if built statically.
  Change default locking_lib to liblvm2clusterlock.so.
  Add skip_dev_dir() to process command line VGs.
  Stop clvmd complaining about nodes that have left the cluster.
  Move lvm_snprintf(), split_words() and split_dm_name() into libdevmapper.
  Add lvconvert man page.
  Add mirror options to man pages.
  Prevent mirror renames.
  Move CMDLIB code into separate file and record whether static build.
* Wed Sep 13 2006 fehr@suse.de
- change BuildRequires to device-mapper-devel
* Mon Aug 21 2006 fehr@suse.de
- update to new version 2.02.09
  Fix PE_ALIGN for pagesize over 32KB.
  Separate out LVM1_PE_ALIGN and pe_align().
  Add lvm_getpagesize wrapper.
  Add --maxphysicalvolumes to vgchange.
* Wed Aug 16 2006 fehr@suse.de
- update to new version 2.02.08
  Add checks for duplicate LV name, lvid and PV id before writing metadata.
  Report all sanity check failures, not just the first.
  Fix missing lockfs on first snapshot creation. (#197850)
  Add unreliable --trustcache option to reporting commands.
  Fix locking for mimage removal.
  Fix clvmd_init_rhel4 'status' exit code.
* Fri Jul 28 2006 olh@suse.de
- remove dropped boot.ibmsis from boot.lvm
- boot.rootfsck should start before boot.lvm (#181972)
* Wed Jul 26 2006 fehr@suse.de
- update to new version 2.02.06
  Fix activation logic in lvchange --persistent.
  Don't ignore persistent minor numbers when activating.
  Fix vgreduce --removemissing to return success if VG is already consistent.
  Fix return code if VG specified on command line is not found.
  Fix PV tools to include orphaned PVs in default output again.
  Prevent snapshots of mirrors.
  Fix lvcreate corelog validation.
  Add --config for overriding most config file settings from cmdline.
  Quote arguments when printing command line.
  Remove linefeed from 'initialising logging' message.
  Add 'Completed' debug message.
  Don't attempt library exit after reloading config files.
  Always compile with libdevmapper, even if device-mapper is disabled.
* Mon May 22 2006 fehr@suse.de
- update to new version 2.02.06
  Propagate --monitor around cluster.
  Add --monitor to vgcreate and lvcreate to control dmeventd registration.
  Filter LCK_NONBLOCK in clvmd lock_vg.
  Add --nosync to lvcreate with LV flag NOTSYNCED.
  Use mirror's uuid for a core log.
  Add mirror log fault-handling policy.
  Improve mirror warning messages and tidy dmeventd syslog output.
  Propagate nosync flag around cluster.
  Allow vgreduce to handle mirror log failures.
  Add --corelog to lvcreate and lvconvert.
  Create a log header for replacement in-sync mirror log.
  Use set_lv() and dev_set() to wipe sections of devices.
  Add mirror_library description to example.conf.
  Fix uuid_from_num() buffer overrun.
  Increase maximum stripe size limit to physical extent size for lvm2 metadata.
  Fix activation code to check for pre-existing mirror logs.
  Ignore empty strings in config files.
  Require non-zero regionsize and document parameter on lvcreate man page.
  Invalidate cache if composition of VG changed externally.
* Wed Apr 26 2006 hare@suse.de
- add LVM_DEVICE_TIMEOUT sysconfig variable to make sure
  udev has finished processing (#149979)
- Fix init script dependencies
* Mon Apr 24 2006 fehr@suse.de
- update to new version 2.02.05
  Fix vgid string termination in recent cache code
* Thu Apr 20 2006 fehr@suse.de
- update to new version 2.02.04
  Check for libsepol.
  Add some cflow & scope support.
  Separate out DEFS from CFLAGS.
  Remove inlines and use unique function names.
* Wed Apr 19 2006 fehr@suse.de
- update to new version 2.02.03
  vgrename accepts vgid and exported VG.
  Add --partial to pvs.
  When choosing between identically-named VGs, also consider creation_host.
  Provide total log suppression with 2.
  Fix vgexport/vgimport to set/reset PV exported flag so pv_attr is correct.
  Add vgid to struct physical_volume and pass with vg_name to some functions.
  If two or more VGs are found with the same name, use one that is not exported.
  Whenever vgname is captured, also capture vgid and whether exported.
  Remove an incorrect unlock_vg() from process_each_lv().
  Update extent size information in vgchange and vgcreate man pages.
  Introduce origin_from_cow() and lv_is_visible().
  pvremove without -f now fails if there's no PV label.
  Support lvconvert -s.
  Suppress locking library load failure message if --ignorelockingfailure.
  Propagate partial mode around cluster.
  Fix archive file expiration.
  Fix dmeventd build.
  clvmd now uses libcman rather than cman ioctls.
  clvmd will allow new cman to shutdown on request.
* Thu Apr  6 2006 fehr@suse.de
- add option --mknodes to vgscan call in /etc/init.d/boot.lvm to
  avoid potential inconsistencies in minor number of dm devices after
  reboot when root fs is LVM LV (#139740)
* Tue Mar 14 2006 fehr@suse.de
- update to new version 2.02.02
  Add %%.so: %%.a make template rule.
  Switchover library building to use LIB_SUFFIX.
  Only do lockfs filesystem sync when suspending snapshots.
  Always print warning if activation is disabled.
  vgreduce removes mirror images.
  Add --mirrorsonly to vgreduce.
  vgreduce replaces active LVs with error segment before removing them.
  Set block_on_error parameter if available.
  Add target_version.
  Add details to format1 'Invalid LV in extent map' error message.
  Fix lvscan snapshot full display.
  Bring lvdisplay man page example into line.
  Add mirror dmeventd library.
  Add some activation logic to remove_mirror_images().
  lvconvert can remove specified PVs from a mirror.
  lvconvert turns an existing LV into a mirror.
  Allow signed mirrors arguments.
  Move create_mirror_log() into toollib.
  Determine parallel PVs to avoid with ALLOC_NORMAL allocation.
  Fix lv_empty.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 fehr@suse.de
- add new binary /sbin/lvconvert to file list
* Tue Dec 13 2005 fehr@suse.de
- add patch lvm-lock.diff to fix bug #138128
* Tue Dec  6 2005 fehr@suse.de
- update to new version 2.02.01
* Tue Nov  8 2005 fehr@suse.de
- add fix_striped_old_format.diff to allow striped volumes with
  old metadata format (#130433)
- add fix_dm_as_pv.diff to allow usage of dm devices as PVs (#129960)
* Mon Oct 17 2005 fehr@suse.de
- update to new version 2.01.15
* Mon Sep 26 2005 fehr@suse.de
- fix bug in pvscan.c with PVs larger than 2TB in VGs
* Thu Aug  4 2005 fehr@suse.de
- update to new version 2.01.14
* Mon Jul 18 2005 fehr@suse.de
- update to new version 2.01.13
* Thu Jun 16 2005 fehr@suse.de
- update to new version 2.01.12
* Wed Jun 15 2005 meissner@suse.de
- add libselinux to nfb to enable selinux support.
- use RPM_OPT_FLAGS.
* Tue Jun 14 2005 fehr@suse.de
- update to new version 2.01.11
* Wed May  4 2005 fehr@suse.de
- update to new version 2.01.10
* Mon Apr 11 2005 fehr@suse.de
- use -y instead of -Y in options for call to fillup_and_insserv
  (#76689)
- update to new version 2.01.09
* Wed Mar  9 2005 fehr@suse.de
- update to new version 2.01.07
* Mon Mar  7 2005 fehr@suse.de
- update to new version 2.01.06
* Thu Feb 10 2005 fehr@suse.de
- update to new version 2.01.04
* Wed Feb  2 2005 fehr@suse.de
- update to new version 2.01.03
* Mon Jan 24 2005 fehr@suse.de
- update to new version 2.01.02
* Thu Jan 20 2005 fehr@suse.de
- update to new version 2.01.01
* Wed Jan 19 2005 fehr@suse.de
- update to new version 2.01.00
* Tue Jan 11 2005 fehr@suse.de
- update to new version 2.00.33
* Wed Jan  5 2005 arvin@suse.de
- update to new version 2.00.32
* Fri Dec 17 2004 arvin@suse.de
- fixed -s option of vgdisplay (bug #49177)
* Mon Nov 29 2004 fehr@suse.de
- update to new version 2.00.29
* Thu Nov 25 2004 fehr@suse.de
- update to new version 2.00.27
* Wed Nov 24 2004 fehr@suse.de
- update to new version 2.00.26
* Wed Sep 29 2004 fehr@suse.de
- update to new version 2.00.25
* Wed Sep 22 2004 fehr@suse.de
- prevent buggy macro for MAJOR in kdev_t.h creep into code via
  include of linux/fs.h
* Mon Sep 20 2004 fehr@suse.de
- update to new version 2.00.24
* Thu Sep 16 2004 fehr@suse.de
- update to new version 2.00.23
* Mon Sep  6 2004 fehr@suse.de
- update to new version 2.00.22
* Mon Aug 23 2004 fehr@suse.de
- update to new version 2.00.21
- new version obsoletes lvm2-vgscan.patch
* Wed Jul 14 2004 fehr@suse.de
- update to new version 2.00.20
* Mon Jun  7 2004 fehr@suse.de
- update to new version 2.00.16
- add forgotten patch no-inc-audit.diff needed for STABLE
* Mon May 24 2004 fehr@suse.de
- update to new version 2.00.15 to fix bug #41020
* Mon May 24 2004 hare@suse.de
- Fixed vgscan on S/390 (readdir returned DT_UNKNOWN)
* Thu May 13 2004 fehr@suse.de
- ignore udev names in default configuration to prevent yast2
  confusion (#36869)
* Mon Apr 19 2004 fehr@suse.de
- accept additional devices (IDE->64, iseries/vd->8, #39114)
* Thu Apr  1 2004 fehr@suse.de
- update to new version 2.00.09 (fixes #34657 and #36877)
* Tue Mar  2 2004 ro@suse.de
- boot.lvm: root-fs is mounted-rw by boot.rootfsck
* Thu Feb 26 2004 fehr@suse.de
- skip cdroms and device with zero size on probing
* Wed Feb  4 2004 fehr@suse.de
- update to new version 2.00.08
- now lvm2 obsoletes lvm
* Thu Sep 18 2003 fehr@suse.de
- fix boot.lvm to cope with LABEL= and UUID= in /etc/fstab
  also check reiser filesystem (#31060)
* Wed Sep 17 2003 fehr@suse.de
- update to new version 2.00.07
* Thu Aug 21 2003 fehr@suse.de
- update to new version 2.00.06
* Mon Aug 18 2003 garloff@suse.de
- (#29083) Add # X-UnitedLinux-Should-Start: boot.scsidev
* Tue Jul  1 2003 fehr@suse.de
- created initial version of a SuSE package
